[Libreoffice-commits] online.git: loleaflet/src

Tor Lillqvist (via logerrit) logerrit at kemper.freedesktop.org
Fri Aug 28 11:36:30 UTC 2020


 loleaflet/src/layer/BackgroundColor.js    |    2 +-
 loleaflet/src/layer/marker/TextInput.js   |    8 ++++----
 loleaflet/src/layer/tile/TileLayer.js     |   10 +++++-----
 loleaflet/src/map/handler/Map.Keyboard.js |    4 ++--
 4 files changed, 12 insertions(+), 12 deletions(-)

New commits:
commit 1bcf147083de59cc2732e4f9ce056cbb8f2f2434
Author:     Tor Lillqvist <tml at collabora.com>
AuthorDate: Fri Aug 28 14:05:13 2020 +0300
Commit:     Tor Lillqvist <tml at collabora.com>
CommitDate: Fri Aug 28 13:36:11 2020 +0200

    Surely it is called loolwsd and not lowsd?
    
    Change-Id: Ie2d8a26fa55de484b6d04e12202ca449d005f7a7
    Reviewed-on: https://gerrit.libreoffice.org/c/online/+/101539
    Tested-by: Jenkins
    Tested-by: Jenkins CollaboraOffice <jenkinscollaboraoffice at gmail.com>
    Reviewed-by: Tor Lillqvist <tml at collabora.com>

diff --git a/loleaflet/src/layer/BackgroundColor.js b/loleaflet/src/layer/BackgroundColor.js
index 31a96ef17..3029657c8 100644
--- a/loleaflet/src/layer/BackgroundColor.js
+++ b/loleaflet/src/layer/BackgroundColor.js
@@ -43,7 +43,7 @@ L.BackgroundColor = L.Layer.extend({
 
 /*
  * A L.BackgroundColor that automatically resets its color
- * based on 'statechange' messages from lowsd.
+ * based on 'statechange' messages from loolwsd.
  */
 L.CalcBackground = L.BackgroundColor.extend({
 	onAdd: function(map) {
diff --git a/loleaflet/src/layer/tile/TileLayer.js b/loleaflet/src/layer/tile/TileLayer.js
index 71340ad89..e7558562c 100644
--- a/loleaflet/src/layer/tile/TileLayer.js
+++ b/loleaflet/src/layer/tile/TileLayer.js
@@ -796,7 +796,7 @@ L.TileLayer = L.GridLayer.extend({
 
 	_onCellAddressMsg: function (textMsg) {
 		// When the user moves the focus to a different cell, a 'cellformula'
-		// message is received from lowsd, *then* a 'celladdress' message.
+		// message is received from loolwsd, *then* a 'celladdress' message.
 		var address = textMsg.substring(13);
 		if (this._map._clip && !this._map['wopi'].DisableCopy) {
 			this._map._clip.setTextSelectionText(this._lastFormula);
@@ -805,10 +805,10 @@ L.TileLayer = L.GridLayer.extend({
 	},
 
 	_onCellFormulaMsg: function (textMsg) {
-		// When a 'cellformula' message from lowsd is received,
+		// When a 'cellformula' message from loolwsd is received,
 		// store the text contents of the cell, but don't push
 		// them to the clipboard container (yet).
-		// This is done because lowsd will send several 'cellformula'
+		// This is done because loolwsd will send several 'cellformula'
 		// messages during text composition, and resetting the contents
 		// of the clipboard container mid-composition will easily break it.
 		var formula = textMsg.substring(13);
@@ -2166,14 +2166,14 @@ L.TileLayer = L.GridLayer.extend({
 		}
 	},
 
-	// Given a character code and a UNO keycode, send a "key" message to lowsd.
+	// Given a character code and a UNO keycode, send a "key" message to loolwsd.
 	//
 	// "type" is either "input" for key presses (akin to the DOM "keypress"
 	// / "beforeinput" events) and "up" for key releases (akin to the DOM
 	// "keyup" event).
 	//
 	// PageUp/PageDown are handled as special cases for spreadsheets - in
-	// addition of sending messages to lowsd, they move the cell cursor around.
+	// addition of sending messages to loolwsd, they move the cell cursor around.
 	postKeyboardEvent: function(type, charCode, unoKeyCode) {
 		var winId = this._map.getWinId();
 		if (
diff --git a/loleaflet/src/map/handler/Map.Keyboard.js b/loleaflet/src/map/handler/Map.Keyboard.js
index 405b73995..852ab07fb 100644
--- a/loleaflet/src/map/handler/Map.Keyboard.js
+++ b/loleaflet/src/map/handler/Map.Keyboard.js
@@ -243,7 +243,7 @@ L.Map.Keyboard = L.Handler.extend({
 	},
 
 	// _handleKeyEvent - checks if the given keyboard event shall trigger
-	// a message to lowsd, and calls the given keyEventFn(type, charcode, keycode)
+	// a message to loolwsd, and calls the given keyEventFn(type, charcode, keycode)
 	// callback if so.
 	// Called from private _onKeyDown
 	_handleKeyEvent: function (ev, keyEventFn) {
@@ -391,7 +391,7 @@ L.Map.Keyboard = L.Handler.extend({
 	},
 
 	// Given a DOM keyboard event that happened while the Control key was depressed,
-	// triggers the appropriate action or lowsd message.
+	// triggers the appropriate action or loolwsd message.
 	_handleCtrlCommand: function (e) {
 		// Control
 		if (e.keyCode == 17)


More information about the Libreoffice-commits mailing list
diff --git a/loleaflet/src/layer/marker/TextInput.js b/loleaflet/src/layer/marker/TextInput.js
index 24af6a272..bae93c25e 100644
--- a/loleaflet/src/layer/marker/TextInput.js
+++ b/loleaflet/src/layer/marker/TextInput.js
@@ -660,10 +660,10 @@ L.TextInput = L.Layer.extend({
 			this._emptyArea();
 	},
 
 	// Sends the given (UTF-8) string of text to lowsd, as IME (text composition)
 	// messages
 	_sendText: function _sendText(text) {
-		this._fancyLog('send-text-to-lowsd', text);
+		this._fancyLog('send-text-to-loolwsd', text);
 
 		// MSIE/Edge cannot compare a string to "\n" for whatever reason,
 		// so compare charcode as well
@@ -792,7 +792,7 @@ L.TextInput = L.Layer.extend({
 	_removeTextContent: function _removeTextContent(before, after) {
 		console.log('Remove ' + before + ' before, and ' + after + ' after');
 
 		/// TODO: rename the event to 'removetextcontent' as soon as lowsd supports it
 		/// TODO: Ask Marco about it
 		this._map._socket.sendMessage(
 			'removetextcontext id=' +
@@ -805,7 +805,7 @@ L.TextInput = L.Layer.extend({
 	// Tiny helper - encapsulates sending a 'textinput' websocket message.
 	// sends a pair of "input" for a composition update paird with an "end"
 	_sendCompositionEvent: function _sendCompositionEvent(text) {
-		console.log('sending to lowsd: ', text);
+		console.log('sending to loolwsd: ', text);
 
 		// We want to trigger auto-correction, but not if we may
 		// have to delete a count of characters in the future,
@@ -660,10 +660,10 @@ L.TextInput = L.Layer.extend({
 	},
 
-	// Sends the given (UTF-8) string of text to lowsd, as IME (text composition)
+	// Sends the given (UTF-8) string of text to loolwsd, as IME (text composition)
 	// messages
 	_sendText: function _sendText(text) {
@@ -792,7 +792,7 @@ L.TextInput = L.Layer.extend({
 		console.log('Remove ' + before + ' before, and ' + after + ' after');
 
-		/// TODO: rename the event to 'removetextcontent' as soon as lowsd supports it
+		/// TODO: rename the event to 'removetextcontent' as soon as loolwsd supports it
 		/// TODO: Ask Marco about it
 		this._map._socket.sendMessage(